@@ -48,7 +48,11 @@
 -- 1 - the given name is invalid. */
 
 int glp_get_rpar(char *name, double *val)
-{     if (strcmp(name, "tol_aij") == 0)
+{     if (strcmp(name, "c0") == 0)
+      {  /* the constant term of the objective function */
+         *val = glp->c0;
+      }
+      else if (strcmp(name, "tol_aij") == 0)
       {  /* tolerance used by the solver to drop small elements of the
             constraint matrix */
          *val = glp->tol_aij;
