@@ -48,7 +48,11 @@
 -- 2 - the given value is invalid. */
 
 int glp_set_rpar(char *name, double val)
-{     if (strcmp(name, "tol_aij") == 0)
+{     if (strcmp(name, "c0") == 0)
+      {  /* the constant term of the objective function */
+         glp->c0 = val;
+      }
+      else if (strcmp(name, "tol_aij") == 0)
       {  /* tolerance used by the solver to drop small elements of the
             constraint matrix */
          if (!(0.0 <= val && val <= 1.0)) return 2;
