@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <math.h>
 #include <stddef.h>
 #include "glpgel.h"
@@ -332,7 +331,7 @@ err:        fault("gel_ft: transformed matrix has invalid pattern");
          else
          {  for (ee = V->col[j]; ee != NULL; ee = ee->col)
               if (ee->col == e) break;
-            assert(ee != NULL);
+            insist(ee != NULL);
             ee->col = e->col;
          }
          /* return the element v[i,j] to the memory pool */
